/*
 * identifier.c
 *
 * Written by Martin J. Schedlbauer.  Copyright 1992, Schedlbauer & Associates.
 * This program is freely distributable without licensing fees and
 * is provided without guarantee or warranty expressed or implied.
 *
 */


#include <stdio.h>

#include <X11/Intrinsic.h>		/* X Toolkit Intrinsics */
#include <X11/StringDefs.h>		/* X Toolkit Intrinsics */

#include <Xm/Xm.h>			/* Motif general include file */
#include <Xm/BulletinB.h>		/* include file for BulletinBoard */

#include <Mrm/MrmPublic.h>		/* Motif Resource Manager */

MrmHierarchy            hierarchy_id;
MrmType                 dummy_class;

String uid_files[] = {
  "identifier.uid"
};

extern void activateCB ();

static MRMRegisterArg cb_names_list[] =
{
  {"activateCB",		(XtPointer) activateCB},
  {"id",			(XtPointer) 1111},
};


main (argc, argv)
     int argc;
     char *argv[];
{
    XtAppContext	app_context;
    Widget		toplevel; 
    Widget		bboard = NULL;  /* IMPORTANT to set to NULL */
    int			n;
    Cardinal		status;

    MrmInitialize ();

    /*
     * initialize toolkit, open a server connection
     * creates and returns an ApplicationShell widget instance
     */
    toplevel = XtVaAppInitialize (
                 &app_context,		/* Application context (returned!) */
		 "SimpleUil",           /* Application Class Name */
                 NULL, 0,               /* Command Line Option List */
                 &argc, argv,           /* Command Line */
                 NULL,                  /* Fallback Resources */
                 NULL);                 /* Terminated VarArgs List */

    hierarchy_id = 0;
    if (MrmOpenHierarchy((MrmCount)(XtNumber(uid_files)),
                      uid_files, 0, &hierarchy_id) != MrmSUCCESS) {
         fprintf (stderr, "can't open Mrm Hierarchy");
    }

    if (MrmRegisterNames(cb_names_list, XtNumber(cb_names_list))
            != MrmSUCCESS) {
        fprintf (stderr, "can't register Mrm Names");
        exit (2);
    }

    XmRegisterConverters();

    status = MrmFetchWidget(hierarchy_id, "main_window", toplevel,
                    &bboard, &dummy_class);

    if (status != MrmSUCCESS)
      XtAppError (app_context, "cannot fetch main_window widget");

    XtManageChild (bboard);

    /*
     * realizing causes X windows to be created
     * needs to be called only once (typically)
     */
    XtRealizeWidget (toplevel);

    XtAppMainLoop (app_context);
				  
} /* end main */



void activateCB (w, tag, call_data)
  Widget w;
  int tag;
  XmPushButtonCallbackStruct *call_data;
{
  printf ("identifier passed from UIL = %d\n", tag);
  exit (0);
} /* end activateCB */
