/*
 * soft_db.c
 *
 * Written by Martin J. Schedlbauer.  Copyright 1992, Schedlbauer & Associates.
 * This program is freely distributable without licensing fees and
 * is provided without guarantee or warranty expressed or implied.
 *
 */


#include <stdio.h>
#include <assert.h>
#include <X11/Intrinsic.h>
#include <softtrack.h>

#define MAX_FAULTS	256


FaultList faults[MAX_FAULTS];
static int nextID = 0;

void DBInit ()
{
  int i;

  for (i = 0; i < MAX_FAULTS; ++i) {
    faults[i] = NULL;
  }
} /* end DBInit */


Cardinal DBStoreFault (id, fault)
  FaultID id;
  Fault *fault;
{
  faults[id] = fault;
} /* end DBStoreFault */


Cardinal DBAddFault (id, fault)
  FaultID id;
  Fault *fault;
{
  faults[id] = fault;
} /* end DBAddFault */


FaultID DBGetNewFaultID ()
{
  assert (++nextID < MAX_FAULTS);
  return (nextID);
} /* end DBGetNewFaultID */


Cardinal DBRemoveFault (id)
  FaultID id;
{
  if (faults[id] != NULL) {
    XtFree (faults[id]->date);
    XtFree (faults[id]->desc);
    XtFree (faults[id]->workaround);
    XtFree (faults[id]->version);
    XtFree (faults[id]->name);
    faults[id] = NULL;
  }
} /* end DBRemoveFault */


FaultList* DBGetMatchingFaults (fault_query)
  Fault *fault_query;
{
  return faults;
} /* end DBGetMatchingFaults */


FaultList DBNewFault (faultID, date, desc, workaround, priority,
                      version, name)
  FaultID faultID;
  String date;
  String desc;
  String workaround;
  Priority priority;
  String version;
  String name;
{
  Fault *fault;

  fault = XtNew (Fault);
  fault->faultID = faultID;
  fault->date = date;
  fault->desc = desc;
  fault->workaround = workaround;
  fault->priority = priority;
  fault->version = version;
  fault->name = name;
 
  return fault; 
} /* end DBNewFault */
